# Generated by Django 2.2.3 on 2019-11-06 17:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('list_based_flavorpack', '0004_auto_20190214_1800'),
    ]

    operations = [
        migrations.AlterField(
            model_name='listbasedregion',
            name='authentication_info',
            field=models.ForeignKey(blank=True, help_text='The Authentication Info to use.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.AuthenticationInfo', verbose_name='Authentication Info'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='end_point',
            field=models.ForeignKey(blank=True, help_text='A protocol-specific endpoint defining whereany data will come from', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_output.EndPoint', verbose_name='End Point'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='rule',
            field=models.ForeignKey(blank=True, help_text='A rule that may be executed by the region processing class.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_capture.Rule', verbose_name='Processing Rule'),
        ),
        migrations.AlterField(
            model_name='listbasedregion',
            name='template',
            field=models.ForeignKey(blank=True, help_text='The Django/Jinja template to send a formatted request for number ranges', null=True, on_delete=django.db.models.deletion.SET_NULL, to='quartet_templates.Template', verbose_name='Message Template'),
        ),
        migrations.AlterField(
            model_name='processingparameters',
            name='list_based_region',
            field=models.ForeignKey(blank=True, help_text='A key-value pair object meant to hold parameters used for processing classes.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='processing_parameters', to='list_based_flavorpack.ListBasedRegion', verbose_name='Processing Class Parameter'),
        ),
    ]
